@@ -406,6 +406,98 @@ class Client:
         """
         return self._make_request(requests.delete, f'/assets/{asset_id}')
 
+    def create_payment_method(self, **optional_args) -> Dict:
+        """Creates a payment_method, calls the POST /paymentMethods endpoint.
+
+        :param name: Name of the payment method
+        :type name: str, optional
+        :param description: Description of the payment method
+        :type description: str, optional
+        :return: PaymentMethod response from REST API
+        :rtype: dict
+
+        :raises: :py:class:`~las.InvalidCredentialsException`, :py:class:`~las.TooManyRequestsException`,\
+ :py:class:`~las.LimitExceededException`, :py:class:`requests.exception.RequestException`
+        """
+        return self._make_request(requests.post, '/paymentMethods', body=optional_args)
+
+    def list_payment_methods(self, *, max_results: Optional[int] = None, next_token: Optional[str] = None) -> Dict:
+        """List payment_methods available, calls the GET /paymentMethods endpoint.
+
+        :param max_results: Maximum number of results to be returned
+        :type max_results: int, optional
+        :param next_token: A unique token for each page, use the returned token to retrieve the next page.
+        :type next_token: str, optional
+        :return: PaymentMethods response from REST API without the content of each payment method
+        :rtype: dict
+
+        :raises: :py:class:`~las.InvalidCredentialsException`, :py:class:`~las.TooManyRequestsException`,\
+ :py:class:`~las.LimitExceededException`, :py:class:`requests.exception.RequestException`
+        """
+        params = {
+            'maxResults': max_results,
+            'nextToken': next_token,
+        }
+        return self._make_request(requests.get, '/paymentMethods', params=params)
+
+    def get_payment_method(self, payment_method_id: str) -> Dict:
+        """Get payment_method, calls the GET /paymentMethods/{paymentMethodId} endpoint.
+
+        :param payment_method_id: Id of the payment method
+        :type payment_method_id: str
+        :return: PaymentMethod response from REST API
+        :rtype: dict
+
+        :raises: :py:class:`~las.InvalidCredentialsException`, :py:class:`~las.TooManyRequestsException`,\
+ :py:class:`~las.LimitExceededException`, :py:class:`requests.exception.RequestException`
+        """
+        return self._make_request(requests.get, f'/paymentMethods/{payment_method_id}')
+
+    def update_payment_method(
+        self,
+        payment_method_id: str,
+        *,
+        stripe_setup_intent_secret: str = None,
+        **optional_args
+    ) -> Dict:
+        """Updates a payment_method, calls the PATCH /paymentMethods/{paymentMethodId} endpoint.
+
+        :param payment_method_id: Id of the payment method
+        :type payment_method_id: str
+        :param stripe_setup_intent_secret: Stripe setup intent secret as returned from create_payment_method
+        :type stripe_setup_intent_secret: str, optional
+        :param name: Name of the payment method
+        :type name: str, optional
+        :param description: Description of the payment method
+        :type description: str, optional
+        :return: PaymentMethod response from REST API
+        :rtype: dict
+
+        :raises: :py:class:`~las.InvalidCredentialsException`, :py:class:`~las.TooManyRequestsException`,\
+ :py:class:`~las.LimitExceededException`, :py:class:`requests.exception.RequestException`
+        """
+
+        body = {**optional_args}
+        if stripe_setup_intent_secret:
+            body['stripeSetupIntentSecret'] = stripe_setup_intent_secret
+
+        return self._make_request(requests.patch, f'/paymentMethods/{payment_method_id}', body=body)
+
+    def delete_payment_method(self, payment_method_id: str) -> Dict:
+        """Delete the payment_method with the provided payment_method_id, calls the DELETE \
+/paymentMethods/{paymentMethodId} endpoint.
+
+        :param payment_method_id: Id of the payment method
+        :type payment_method_id: str
+        :return: PaymentMethod response from REST API
+        :rtype: dict
+
+        :raises: :py:class:`~las.InvalidCredentialsException`, :py:class:`~las.TooManyRequestsException`,\
+ :py:class:`~las.LimitExceededException`, :py:class:`requests.exception.RequestException`
+        """
+
+        return self._make_request(requests.delete, f'/paymentMethods/{payment_method_id}')
+
     def create_dataset(self, *, metadata: Optional[dict] = None, **optional_args) -> Dict:
         """Creates a dataset, calls the POST /datasets endpoint.
 
@@ -557,6 +649,8 @@ class Client:
         dataset_id: Optional[Queryparam] = None,
         max_results: Optional[int] = None,
         next_token: Optional[str] = None,
+        order: Optional[str] = None,
+        sort_by: Optional[str] = None,
     ) -> Dict:
         """List documents available for inference, calls the GET /documents endpoint.
 
@@ -572,6 +666,10 @@ class Client:
         :type max_results: int, optional
         :param next_token: A unique token for each page, use the returned token to retrieve the next page.
         :type next_token: str, optional
+        :param order: Order of the executions, either 'ascending' or 'descending'
+        :type order: str, optional
+        :param sort_by: the sorting variable of the executions, currently only supports 'createdTime'
+        :type sort_by: str, optional
         :return: Documents response from REST API
         :rtype: dict
 
@@ -583,8 +681,10 @@ class Client:
             'datasetId': dataset_id,
             'maxResults': max_results,
             'nextToken': next_token,
+            'order': order,
+            'sortBy': sort_by,
         }
-        return self._make_request(requests.get, '/documents', params=params)
+        return self._make_request(requests.get, '/documents', params=dictstrip(params))
 
     def delete_documents(
         self,
@@ -1109,12 +1209,16 @@ class Client:
     def update_organization(
         self,
         organization_id: str,
+        *,
+        payment_method_id: str = None,
         **optional_args,
     ) -> Dict:
         """Updates an organization, calls the PATCH /organizations/{organizationId} endpoint.
 
-        :param organization_id: The Id of the organization
+        :param organization_id: Id of organization
         :type organization_id: str, optional
+        :param payment_method_id: Id of paymentMethod to use
+        :type payment_method_id: str, optional
         :param name: Name of the organization
         :type name: str, optional
         :param description: Description of the organization
@@ -1125,7 +1229,11 @@ class Client:
         :raises: :py:class:`~las.InvalidCredentialsException`, :py:class:`~las.TooManyRequestsException`,\
  :py:class:`~las.LimitExceededException`, :py:class:`requests.exception.RequestException`
         """
-        return self._make_request(requests.patch, f'/organizations/{organization_id}', body=optional_args)
+        body = {**optional_args}
+        if payment_method_id:
+            body['paymentMethodId'] = payment_method_id
+
+        return self._make_request(requests.patch, f'/organizations/{organization_id}', body=body)
 
     def create_prediction(
         self,
@@ -1188,7 +1296,14 @@ class Client:
         }
         return self._make_request(requests.post, '/predictions', body=dictstrip(body))
 
-    def list_predictions(self, *, max_results: Optional[int] = None, next_token: Optional[str] = None) -> Dict:
+    def list_predictions(
+        self,
+        *,
+        max_results: Optional[int] = None,
+        next_token: Optional[str] = None,
+        order: Optional[str] = None,
+        sort_by: Optional[str] = None,
+    ) -> Dict:
         """List predictions available, calls the GET /predictions endpoint.
 
         >>> from las.client import Client
@@ -1199,6 +1314,10 @@ class Client:
         :type max_results: int, optional
         :param next_token: A unique token for each page, use the returned token to retrieve the next page.
         :type next_token: str, optional
+        :param order: Order of the executions, either 'ascending' or 'descending'
+        :type order: str, optional
+        :param sort_by: the sorting variable of the executions, currently only supports 'createdTime'
+        :type sort_by: str, optional
         :return: Predictions response from REST API without the content of each prediction
         :rtype: dict
 
@@ -1208,8 +1327,10 @@ class Client:
         params = {
             'maxResults': max_results,
             'nextToken': next_token,
+            'order': order,
+            'sortBy': sort_by,
         }
-        return self._make_request(requests.get, '/predictions', params=params)
+        return self._make_request(requests.get, '/predictions', params=dictstrip(params))
 
     def get_plan(self, plan_id: str) -> Dict:
         """Get information about a specific plan, calls the GET /plans/{plan_id} endpoint.
